"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
class Header {
    constructor(br) {
        const startPos = br.pos;
        this.version = br.readReverse(4);
        this.prevHash = br.readReverse(32);
        this.merkleRoot = br.readReverse(32);
        this.time = br.readUInt32LE();
        this.bits = br.readReverse(4);
        this.nonce = br.readUInt32LE();
        this.buffer = br.slice(startPos, br.pos);
    }
    static fromBuffer(buf) {
        const br = new utils_1.BufferReader(buf);
        return this.fromBufferReader(br);
    }
    static fromBufferReader(br) {
        const header = new Header(br);
        return header;
    }
    static fromHex(hex) {
        const buf = Buffer.from(hex, "hex");
        return Header.fromBuffer(buf);
    }
    toBuffer() {
        return this.buffer;
    }
    toHex() {
        return this.toBuffer().toString("hex");
    }
    getHash(hexStr = false) {
        if (!this.hash) {
            const buf = this.toBuffer();
            this.hash = utils_1.Hash.sha256sha256(buf).reverse();
        }
        return hexStr ? this.hash.toString("hex") : this.hash;
    }
}
exports.default = Header;
//# sourceMappingURL=header.js.map