/// <reference types="node" />
import Script, { ScriptGetBitcoms, ScriptInitOptions, ScriptBitcom } from "./script";
import { BufferReader, BufferChunksReader } from "./utils";
export interface TransactionInput {
    vin: number;
    scriptBuffer: Buffer;
    prevTxId: Buffer;
    vout: number;
    sequenceNumber: number;
    segwitItems?: Buffer[];
}
export interface TransactionOutput {
    satoshis: number;
    scriptBuffer: Buffer;
    vout: number;
}
export interface TransactionOptions {
    disableSegwit?: boolean;
}
export default class Transaction {
    bufStart: number;
    segwitFlag?: number;
    segwitItems?: number;
    inputs: TransactionInput[];
    outputs: TransactionOutput[];
    version: number;
    sizeTxIns: number;
    sizeTxOuts: number;
    nLockTime: number;
    bufEnd: number;
    buffer: Buffer;
    bufferTx?: Buffer;
    hash?: Buffer;
    txid?: string;
    length: number;
    private constructor();
    static fromBuffer(buf: Buffer, options?: TransactionOptions): Transaction;
    static fromBufferReader(br: BufferReader | BufferChunksReader, options?: TransactionOptions): Transaction;
    static fromHex(txhex: string, options?: TransactionOptions): Transaction;
    toTxBuffer(): Buffer;
    toBuffer(): Buffer;
    toHex(): string;
    getHash(): Buffer;
    getTxid(): string;
    getWTxid(): string;
    getScripts(options: ScriptInitOptions): [number, Script][];
    getOpReturns(options?: {
        singleOpReturn: boolean;
    }): [number, Buffer[][]][];
    parseBitcoms(options?: {
        singleOpReturn: boolean;
    }): ScriptBitcom[];
    getBitcoms(options?: ScriptGetBitcoms): Set<string>;
    getCoinbaseHeight(): number;
}
//# sourceMappingURL=transaction.d.ts.map